# Основные понятия

## Модель дизайна

- Python объявляет маршруты и обработчики
- Rust выполняет сетевую работу/работу во время выполнения.
- `Context` содержит метаданные запроса.

## Правила обработчика

- Должно быть `async def`
- Первый аргумент должен быть `ctx`.
- Дополнительные типизированные аргументы привязаны к маршруту/запросу.

## Владение средой выполнения

`app.run()` запускает собственную среду выполнения и рабочую модель.